@@ -10,9 +10,6 @@ from collections import OrderedDict
 from fontbakery.checkrunner import (
               distribute_generator
             , CheckRunner
-            , ValueValidationError
-            , Profile
-            , get_module_profile
             , get_module_from_file
             , DEBUG
             , INFO
@@ -22,12 +19,18 @@ from fontbakery.checkrunner import (
             , PASS
             , FAIL
             , SECTIONSUMMARY
-            , START
-            , END
-            , ENDCHECK
             )
+from fontbakery.configuration import Configuration
+from fontbakery.profile import (Profile, get_module_profile)
 
+from fontbakery.errors import ValueValidationError
 from fontbakery.multiproc import multiprocessing_runner
+from fontbakery.reporters.terminal import TerminalReporter
+from fontbakery.reporters.serialize import SerializeReporter
+from fontbakery.reporters.ghmarkdown import GHMarkdownReporter
+from fontbakery.reporters.html import HTMLReporter
+from fontbakery.utils import get_theme
+
 
 log_levels =  OrderedDict((s.name, s) \
                           for s in sorted((
@@ -42,10 +45,18 @@ log_levels =  OrderedDict((s.name, s) \
 
 DEFAULT_LOG_LEVEL = INFO
 
-from fontbakery.reporters.terminal import TerminalReporter
-from fontbakery.reporters.serialize import SerializeReporter
-from fontbakery.reporters.ghmarkdown import GHMarkdownReporter
-from fontbakery.reporters.html import HTMLReporter
+
+class AddReporterAction(argparse.Action):
+     def __init__(self, option_strings, dest, nargs=None, **kwargs):
+        self.cls = kwargs["cls"]
+        del kwargs["cls"]
+        super().__init__(option_strings, dest, **kwargs)
+
+     def __call__(self, parser, namespace, values, option_string=None):
+        if not hasattr(namespace, "reporters"):
+            namespace.reporters = []
+        namespace.reporters.append((self.cls, values))
+
 
 def ArgumentParser(profile, profile_arg=True):
     argument_parser = \
@@ -60,6 +71,10 @@ def ArgumentParser(profile, profile_arg=True):
 
     values_keys = profile.setup_argparse(argument_parser)
 
+    argument_parser.add_argument('--configuration',
+                                 dest='configfile',
+                                 help='Read configuration file (TOML/YAML).\n')
+
     argument_parser.add_argument(
         "-c",
         "--checkid",
@@ -137,16 +152,15 @@ def ArgumentParser(profile, profile_arg=True):
     argument_parser.add_argument('--light-theme', default=False, action='store_true',
                                  help='Use a color theme with light colors.')
 
-    argument_parser.add_argument('--json', default=False, type=argparse.FileType('w'),
+    argument_parser.add_argument('--json', default=False, action=AddReporterAction, cls=SerializeReporter,
                                  metavar= 'JSON_FILE',
                                  help='Write a json formatted report to JSON_FILE.')
 
-    argument_parser.add_argument('--ghmarkdown', default=False, type=argparse.FileType('w'),
+    argument_parser.add_argument('--ghmarkdown', default=False, action=AddReporterAction, cls=GHMarkdownReporter,
                                  metavar= 'MD_FILE',
                                  help='Write a GitHub-Markdown formatted report to MD_FILE.')
 
-    argument_parser.add_argument('--html', default=False,
-                                 type=argparse.FileType('w', encoding="utf-8"),
+    argument_parser.add_argument('--html', default=False,action=AddReporterAction, cls=HTMLReporter,
                                  metavar= 'HTML_FILE',
                                  help='Write a HTML report to HTML_FILE.')
 
@@ -234,11 +248,6 @@ def get_profile():
         raise Exception(f"Can't get a profile from {imported}.")
     return profile
 
-# This stub or alias is kept for compatibility (e.g. check-commands, FontBakery
-# Dashboard). The function of the same name previously only passed on all parameters to
-# CheckRunner.
-runner_factory = CheckRunner
-
 def main(profile=None, values=None):
     # profile can be injected by e.g. check-googlefonts injects it's own profile
     add_profile_arg = False
@@ -255,34 +264,12 @@ def main(profile=None, values=None):
         args.no_progress = True
         args.no_colors = True
 
-    from fontbakery.constants import NO_COLORS_THEME, DARK_THEME, LIGHT_THEME
-    if args.no_colors:
-        theme = NO_COLORS_THEME
-    else:
-        if args.light_theme:
-            theme = LIGHT_THEME
-        elif args.dark_theme:
-            theme = DARK_THEME
-        elif sys.platform == "darwin":
-            # The vast majority of MacOS users seem to use a light-background on the text terminal
-            theme = LIGHT_THEME
-        else:
-            # For orther systems like GNU+Linux and Windows, a dark terminal seems to be more common.
-            theme = DARK_THEME
-
+    theme = get_theme(args)
+    # the most verbose loglevel wins
+    loglevel = min(args.loglevels) if args.loglevels else DEFAULT_LOG_LEVEL
 
     if args.list_checks:
-        if args.loglevels == [PASS]: # if verbose:
-            for section in profile._sections.values():
-                print(theme["list-checks: section"]("\nSection:") + " " + section.name)
-                for check in section._checks:
-                    print(theme["list-checks: check-id"](check.id) + "\n" +
-                          theme["list-checks: description"](f'"{check.description}"') + "\n")
-        else:
-            for section_name, section in profile._sections.items():
-                for check in section._checks:
-                    print(check.id)
-        sys.exit()
+        list_checks(profile, theme, verbose=loglevel > DEFAULT_LOG_LEVEL)
 
     values_ = {}
     if values is not None:
@@ -295,11 +282,18 @@ def main(profile=None, values=None):
             if hasattr(args, key):
                 values_[key] = getattr(args, key)
 
-    runner_kwds = dict( values=values_
-                      , custom_order=args.order
-                      , explicit_checks=args.checkid
-                      , exclude_checks=args.exclude_checkid
-                      )
+    if args.configfile:
+        configuration = Configuration.from_config_file(args.configfile)
+    else:
+        configuration = Configuration()
+
+    # Command line args overrides config, but only if given
+    configuration.maybe_override(Configuration(
+        custom_order=args.order,
+        explicit_checks=args.checkid,
+        exclude_checks=args.exclude_checkid
+    ))
+    runner_kwds = dict(values=values_, config=configuration)
     try:
         runner = CheckRunner(profile, **runner_kwds)
     except ValueValidationError as e:
@@ -309,8 +303,6 @@ def main(profile=None, values=None):
 
     is_async = args.multiprocessing != 0
 
-    # the most verbose loglevel wins
-    loglevel = min(args.loglevels) if args.loglevels else DEFAULT_LOG_LEVEL
     tr = TerminalReporter(runner=runner, is_async=is_async
                          , print_progress=not args.no_progress
                          , succinct=args.succinct
@@ -321,49 +313,44 @@ def main(profile=None, values=None):
                          , skip_status_report=None if args.show_sections \
                                                    else (SECTIONSUMMARY, )
                          )
-    reporters = [tr.receive]
+    reporters = [tr]
+    if "reporters" not in args:
+        args.reporters = []
 
-    if args.json:
-        sr = SerializeReporter(runner=runner, collect_results_by=args.gather_by)
-        reporters.append(sr.receive)
-
-    if args.ghmarkdown:
-        mdr = GHMarkdownReporter(loglevels=args.loglevels,
-                                 runner=runner,
-                                 collect_results_by=args.gather_by)
-        reporters.append(mdr.receive)
-
-    if args.html:
-        hr = HTMLReporter(loglevels=args.loglevels,
-                          runner=runner,
-                          collect_results_by=args.gather_by)
-        reporters.append(hr.receive)
+    for reporter_class, output_file in args.reporters:
+        reporters.append(reporter_class(loglevels=args.loglevels,
+                             runner=runner,
+                             collect_results_by=args.gather_by,
+                             output_file=output_file
+                         ))
 
     if args.multiprocessing == 0:
         status_generator = runner.run()
     else:
         status_generator = multiprocessing_runner(args.multiprocessing, runner, runner_kwds)
 
-    distribute_generator(status_generator, reporters)
+    distribute_generator(status_generator, [reporter.receive for reporter in reporters])
 
-    if args.json:
-        import json
-        json.dump(sr.getdoc(), args.json, sort_keys=True, indent=4)
-        print(f'A report in JSON format has been'
-              f' saved to "{args.json.name}"')
-
-    if args.ghmarkdown:
-        args.ghmarkdown.write(mdr.get_markdown())
-        print(f'A report in GitHub Markdown format which can be useful\n'
-              f' for posting issues on a GitHub issue tracker has been\n'
-              f' saved to "{args.ghmarkdown.name}"')
-
-    if args.html:
-        args.html.write(hr.get_html())
-        print(f'A report in HTML format has been saved to "{args.html.name}"')
+    for reporter in reporters:
+        reporter.write()
 
     # Fail and error let the command fail
     return 1 if tr.worst_check_status in (ERROR, FAIL) else 0
 
+
+def list_checks(profile, theme, verbose=False):
+    if verbose:
+        for section in profile._sections.values():
+            print(theme["list-checks: section"]("\nSection:") + " " + section.name)
+            for check in section._checks:
+                print(theme["list-checks: check-id"](check.id) + "\n" +
+                      theme["list-checks: description"](f'"{check.description}"') + "\n")
+    else:
+        for _, section in profile._sections.items():
+            for check in section._checks:
+                print(check.id)
+    sys.exit()
+
+
 if __name__ == '__main__':
     sys.exit(main())
