@@ -1,11 +1,12 @@
 from fontbakery.message import Message
 from fontbakery.callable import check
-from fontbakery.checkrunner import FAIL, PASS, WARN
+from fontbakery.status import FAIL, PASS, WARN
 # used to inform get_module_profile whether and how to create a profile
 from fontbakery.fonts_profile import profile_factory # NOQA pylint: disable=unused-import
 
 import fontTools.ttLib
 
+
 @check(
     id = 'com.google.fonts/check/glyf_unused_data',
     conditions = ['is_ttf']
@@ -128,6 +129,7 @@ def com_google_fonts_check_glyf_non_transformed_duplicate_components(ttFont):
         yield PASS, ("Glyphs do not contain duplicate components which have"
                      " the same x,y coordinates.")
 
+
 @check(
     id = 'com.google.fonts/check/glyf_nested_components',
     rationale = """
