@@ -2,7 +2,12 @@ import os
 import re
 
 from fontbakery.callable import condition
-from fontbakery.constants import NameID
+from fontbakery.constants import (
+    NameID,
+    PlatformID,
+    UnicodeEncodingID,
+    WindowsLanguageID
+)
 
 # -------------------------------------------------------------------
 # FIXME! Redundant with @condition canonical_stylename(font)?
@@ -164,6 +169,12 @@ def registered_vendor_ids():
     CACHED = resource_filename('fontbakery',
                                'data/fontbakery-microsoft-vendorlist.cache')
     content = open(CACHED, encoding='utf-8').read()
+    # Strip all <A> HTML tags from the raw HTML. The current page contains a
+    # closing </A> for which no opening <A> is present, which causes
+    # beautifulsoup to silently stop processing that section from the error
+    # onwards. We're not using the href's anyway.
+    content = re.sub("<a[^>]*>", "", content, flags=re.IGNORECASE)
+    content = re.sub("</a>", "", content, flags=re.IGNORECASE)
     soup = BeautifulSoup(content, 'html.parser')
 
     IDs = [chr(c + ord('a')) for c in range(ord('z') - ord('a') + 1)]
@@ -248,8 +259,11 @@ def license_contents(license_path):
 @condition
 def license_path(licenses):
     """Get license path."""
-    # return license if there is exactly one license
-    return licenses[0] if len(licenses) == 1 else None
+    # This assumes that a repo can have multiple license files
+    # and they're all the same.
+    # FIXME: We should have a fontbakery check for that, though!
+    if licenses and len(licenses) > 0:
+        return licenses[0]
 
 
 @condition
@@ -272,28 +286,45 @@ def familyname(font):
         return filename_base
 
 
+@condition
+def installed_ttfa():
+   import subprocess
+   ttfa_cmd = ["ttfautohint",
+               "-V"]  # print version info
+   try:
+       ttfa_output = subprocess.check_output(ttfa_cmd,
+                                             stderr=subprocess.STDOUT)
+   except FileNotFoundError:
+       return None
+
+   installed = re.search(r'ttfautohint ([^-\n]*)(-.*)?\n',
+                         ttfa_output.decode('utf-8')).group(1)
+   return installed
+
+
 @condition
 def hinting_stats(font):
     """
     Return file size differences for a hinted font compared to an dehinted version of same file
     """
-    from ttfautohint import ttfautohint, libttfautohint
     from io import BytesIO
+    from dehinter.font import dehint
     from fontTools.ttLib import TTFont
     from fontTools.subset import main as pyftsubset
     from fontbakery.profiles.shared_conditions import (is_ttf,
                                                        is_cff,
                                                        is_cff2)
 
-    if is_ttf(TTFont(font)):
-        original_buffer = BytesIO()
-        TTFont(font).save(original_buffer)
-        dehinted_buffer = ttfautohint(in_buffer=original_buffer.getvalue(),
-                                      dehint=True)
-        dehinted_size = len(dehinted_buffer)
-        version = libttfautohint.version_string
+    hinted_size = os.stat(font).st_size
+    ttFont = TTFont(font)
 
-    elif is_cff(TTFont(font)) or is_cff2(TTFont(font)):
+    if is_ttf(ttFont):
+        dehinted_buffer = BytesIO()
+        dehint(ttFont, verbose=False)
+        ttFont.save(dehinted_buffer)
+        dehinted_buffer.seek(0)
+        dehinted_size = len(dehinted_buffer.read())
+    elif is_cff(ttFont) or is_cff2(ttFont):
         ext = os.path.splitext(font)[1]
         tmp = font.replace(ext, "-tmp-dehinted%s" % ext)
         args = [font,
@@ -312,7 +343,6 @@ def hinting_stats(font):
         pyftsubset(args)
 
         dehinted_size = os.stat(tmp).st_size
-        version = "" # TODO If there is a way, extract the psautohint version used?
         os.remove(tmp)
 
     else:
@@ -320,8 +350,7 @@ def hinting_stats(font):
 
     return {
         "dehinted_size": dehinted_size,
-        "hinted_size": os.stat(font).st_size,
-        "version": version
+        "hinted_size": hinted_size,
     }
 
 
@@ -414,7 +443,7 @@ def remote_styles(familyname_with_spaces):
         from fontbakery.utils import download_file
         url_prefix = 'https://fonts.google.com/download?family='
         url = '{}{}'.format(url_prefix, familyname.replace(' ', '+'))
-        return ZipFile(download_file(url))
+        return ZipFile(download_file(url))  # pylint: disable=R1732
 
 
     def fonts_from_zip(zipfile):
@@ -442,6 +471,44 @@ def remote_styles(familyname_with_spaces):
     return rstyles
 
 
+@condition
+def regular_remote_style(remote_styles):
+    from .shared_conditions import is_variable_font, get_instance_axis_value
+    if not remote_styles:
+        return None
+    if "Regular" in remote_styles:
+        return remote_styles["Regular"]
+
+    for style, font in remote_styles.items():
+        if is_variable_font(font):
+            if get_instance_axis_value(font, "Regular", "wght"):
+                return font
+    return list(remote_styles.items())[0][1]
+
+
+@condition
+def regular_ttFont(ttFonts):
+    from .shared_conditions import is_variable_font, get_instance_axis_value
+    for ttFont in ttFonts:
+        if "-Regular." in os.path.basename(ttFont.reader.file.name):
+            return ttFont
+        nametable = ttFont['name']
+        sub_family = nametable.getName(NameID.FONT_SUBFAMILY_NAME,
+                                       PlatformID.WINDOWS,
+                                       UnicodeEncodingID.UNICODE_1_1,
+                                       WindowsLanguageID.ENGLISH_USA)
+        typo_sub_family = nametable.getName(NameID.TYPOGRAPHIC_SUBFAMILY_NAME,
+                                            PlatformID.WINDOWS,
+                                            UnicodeEncodingID.UNICODE_1_1,
+                                            WindowsLanguageID.ENGLISH_USA)
+        if sub_family and sub_family.toUnicode() == "Regular" and not typo_sub_family:
+            return ttFont
+        if is_variable_font(ttFont):
+            if get_instance_axis_value(ttFont, "Regular", "wght"):
+                return ttFont
+    return None
+
+
 @condition
 def api_gfonts_ttFont(style, remote_styles):
     """Get a TTFont object of a font downloaded from Google Fonts
@@ -469,11 +536,9 @@ def github_gfonts_ttFont(ttFont, license):
         "LICENSE.txt": "apache"
     }
     filename = os.path.basename(ttFont.reader.file.name)
-    fontname = filename.split('-')[0].lower()
-    url = ("https://github.com/google/fonts/raw/master"
-           "/{}/{}/{}").format(LICENSE_DIRECTORY[license],
-                               fontname,
-                               filename)
+    familyname = filename.split('-')[0].lower()
+    url = (f"https://github.com/google/fonts/raw/main"
+           f"/{LICENSE_DIRECTORY[license]}/{familyname}/{filename}")
     try:
         fontfile = download_file(url)
         if fontfile:
@@ -482,6 +547,34 @@ def github_gfonts_ttFont(ttFont, license):
         return None
 
 
+@condition
+def github_gfonts_description(ttFont, license):
+    """Get the contents of the DESCRIPTION.en_us.html file
+       from the google/fonts github repository corresponding
+       to a given ttFont.
+    """
+    if not license:
+        return None
+
+    from fontbakery.utils import download_file
+    from urllib.request import HTTPError
+    LICENSE_DIRECTORY = {
+        "OFL.txt": "ofl",
+        "UFL.txt": "ufl",
+        "LICENSE.txt": "apache"
+    }
+    filename = os.path.basename(ttFont.reader.file.name)
+    familyname = filename.split('-')[0].lower()
+    url = (f"https://github.com/google/fonts/raw/main"
+           f"/{LICENSE_DIRECTORY[license]}/{familyname}/DESCRIPTION.en_us.html")
+    try:
+        descfile = download_file(url)
+        if descfile:
+            return descfile.read().decode('UTF-8')
+    except HTTPError:
+        return None
+
+
 @condition
 def familyname_with_spaces(familyname):
     """Attempts to build family name from font name.
