@@ -109,6 +109,8 @@ def superfamily_ttFonts(superfamily):
 
 @condition
 def ligatures(ttFont):
+    from fontTools.ttLib.tables.otTables import LigatureSubst
+
     all_ligatures = {}
     try:
         if "GSUB" in ttFont and ttFont["GSUB"].table.LookupList:
@@ -117,7 +119,7 @@ def ligatures(ttFont):
                     for index in record.Feature.LookupListIndex:
                         lookup = ttFont["GSUB"].table.LookupList.Lookup[index]
                         for subtable in lookup.SubTable:
-                            if subtable.Format == 1:
+                            if isinstance(subtable, LigatureSubst):
                                 for firstGlyph in subtable.ligatures.keys():
                                     all_ligatures[firstGlyph] = []
                                     for lig in subtable.ligatures[firstGlyph]:
@@ -130,6 +132,8 @@ def ligatures(ttFont):
 
 @condition
 def ligature_glyphs(ttFont):
+    from fontTools.ttLib.tables.otTables import LigatureSubst
+
     all_ligature_glyphs = []
     try:
         if "GSUB" in ttFont and ttFont["GSUB"].table.LookupList:
@@ -138,7 +142,7 @@ def ligature_glyphs(ttFont):
                     for index in record.Feature.LookupListIndex:
                         lookup = ttFont["GSUB"].table.LookupList.Lookup[index]
                         for subtable in lookup.SubTable:
-                            if subtable.Format == 1:
+                            if isinstance(subtable, LigatureSubst):
                                 for firstGlyph in subtable.ligatures.keys():
                                     for lig in subtable.ligatures[firstGlyph]:
                                         if lig.LigGlyph not in all_ligature_glyphs:
@@ -153,16 +157,48 @@ def glyph_metrics_stats(ttFont):
     """Returns a dict containing whether the font seems_monospaced,
     what's the maximum glyph width and what's the most common width.
 
-    For a font to be considered monospaced, at least 80% of
-    the ascii glyphs must have the same width."""
+    For a font to be considered monospaced, if at least 80% of ASCII
+    characters have glyphs, then at least 80% of those must have the same
+    width, otherwise all glyphs of printable characters must have one of
+    two widths or be zero-width.
+    """
     glyph_metrics = ttFont['hmtx'].metrics
-    ascii_glyph_names = [ttFont.getBestCmap()[c] for c in range(32, 128)
+    # NOTE: `range(a, b)` includes `a` and does not include `b`.
+    #       Here we don't include 0-31 as well as 127
+    #       because these are control characters.
+    ascii_glyph_names = [ttFont.getBestCmap()[c] for c in range(32, 127)
                          if c in ttFont.getBestCmap()]
-    ascii_widths = [adv for name, (adv, lsb) in glyph_metrics.items()
-                    if name in ascii_glyph_names and adv != 0]
-    ascii_width_count = Counter(ascii_widths)
-    ascii_most_common_width = ascii_width_count.most_common(1)[0][1]
-    seems_monospaced = ascii_most_common_width >= len(ascii_widths) * 0.8
+
+    if len(ascii_glyph_names) > 0.8 * (127 - 32):
+        ascii_widths = [adv for name, (adv, lsb) in glyph_metrics.items()
+                        if name in ascii_glyph_names and adv != 0]
+        ascii_width_count = Counter(ascii_widths)
+        ascii_most_common_width = ascii_width_count.most_common(1)[0][1]
+        seems_monospaced = ascii_most_common_width >= len(ascii_widths) * 0.8
+    else:
+        from fontTools import unicodedata
+        # Collect relevant glyphs.
+        relevant_glyph_names = set()
+        # Add character glyphs that are in one of these categories:
+        # Letter, Mark, Number, Punctuation, Symbol, Space_Separator.
+        # This excludes Line_Separator, Paragraph_Separator and Control.
+        for value, name in ttFont.getBestCmap().items():
+            if unicodedata.category(chr(value)).startswith(
+                ("L", "M", "N", "P", "S", "Zs")
+            ):
+                relevant_glyph_names.add(name)
+        # Remove character glyphs that are mark glyphs.
+        gdef = ttFont.get("GDEF")
+        if gdef:
+            marks = {name
+                     for name, c in gdef.table.GlyphClassDef.classDefs.items()
+                     if c == 3
+                    }
+            relevant_glyph_names.difference_update(marks)
+
+        widths = sorted({adv for name, (adv, lsb) in glyph_metrics.items()
+                         if name in relevant_glyph_names and adv != 0})
+        seems_monospaced = len(widths) <= 2
 
     width_max = max([adv for k, (adv, lsb) in glyph_metrics.items()])
     most_common_width = Counter([g for g in glyph_metrics.values()
@@ -350,6 +386,20 @@ def is_cjk_font(ttFont):
     return False
 
 
+@condition
+def get_cjk_glyphs(ttFont):
+    """Return all glyphs which belong to a CJK unicode block"""
+    from fontbakery.constants import CJK_UNICODE_RANGES
+    results = []
+    cjk_unicodes = set()
+    for start, end in CJK_UNICODE_RANGES:
+        cjk_unicodes |= set(u for u in range(start, end+1))
+    for uni, glyph_name in ttFont.getBestCmap().items():
+        if uni in cjk_unicodes:
+            results.append(glyph_name)
+    return results
+
+
 @condition
 def typo_metrics_enabled(ttFont):
     return ttFont['OS/2'].fsSelection & 0b10000000 > 0
