@@ -1,14 +1,17 @@
 import os
 
-from fontbakery.checkrunner import Section, PASS, FAIL, WARN, ERROR, INFO, SKIP
+from fontbakery.status import PASS, FAIL, WARN, ERROR, INFO, SKIP
+from fontbakery.section import Section
 from fontbakery.callable import condition, check, disable
 from fontbakery.message import Message
 from fontbakery.fonts_profile import profile_factory
 from fontbakery.profiles.opentype import OPENTYPE_PROFILE_CHECKS
 from fontbakery.profiles.outline import OUTLINE_PROFILE_CHECKS
+from fontbakery.profiles.shaping import PROFILE_CHECKS as SHAPING_PROFILE_CHECKS
 
 profile_imports = ('fontbakery.profiles.opentype',
                    'fontbakery.profiles.outline',
+                   'fontbakery.profiles.shaping',
                    '.shared_conditions')
 profile = profile_factory(default_section=Section("Universal"))
 
@@ -27,6 +30,7 @@ UNIVERSAL_PROFILE_CHECKS = \
     OPENTYPE_PROFILE_CHECKS + \
     OUTLINE_PROFILE_CHECKS + \
     THIRDPARTY_CHECKS + \
+    SHAPING_PROFILE_CHECKS + \
     SUPERFAMILY_CHECKS + [
         'com.google.fonts/check/name/trailing_spaces',
         'com.google.fonts/check/family/win_ascent_and_descent',
@@ -65,9 +69,11 @@ def com_google_fonts_check_name_trailing_spaces(ttFont):
             shortened_str = name_record.toUnicode()
             if len(shortened_str) > 20:
                 shortened_str = shortened_str[:10] + "[...]" + shortened_str[-10:]
-            yield FAIL, (f"Name table record with key = {name_key} has"
-                         f" trailing spaces that must be removed:"
-                         f" '{shortened_str}'")
+            yield FAIL, \
+                  Message("trailing-space",
+                          f"Name table record with key = {name_key} has"
+                          f" trailing spaces that must be removed:"
+                          f" '{shortened_str}'")
     if not failed:
         yield PASS, ("No trailing spaces on name table entries.")
 
@@ -135,6 +141,11 @@ def com_google_fonts_check_family_win_ascent_and_descent(ttFont, vmetrics):
     id = 'com.google.fonts/check/os2_metrics_match_hhea',
     conditions = ['not is_cjk_font'],
     rationale = """
+        OS/2 and hhea vertical metric values should match. This will produce the same linespacing on Mac, GNU+Linux and Windows.
+
+        - Mac OS X uses the hhea values.
+        - Windows uses OS/2 or Win, depending on the OS or fsSelection bit value.
+
         When OS/2 and hhea vertical metrics match, the same linespacing results on macOS, GNU+Linux and Windows. Unfortunately as of 2018, Google Fonts has released many fonts with vertical metrics that don't match in this way. When we fix this issue in these existing families, we will create a visible change in line/paragraph layout for either Windows or macOS users, which will upset some of them.
 
         But we have a duty to fix broken stuff, and inconsistent paragraph layout is unacceptably broken when it is possible to avoid it.
@@ -143,14 +154,7 @@ def com_google_fonts_check_family_win_ascent_and_descent(ttFont, vmetrics):
     """
 )
 def com_google_fonts_check_os2_metrics_match_hhea(ttFont):
-    """Checking OS/2 Metrics match hhea Metrics.
-
-    OS/2 and hhea vertical metric values should match. This will produce
-    the same linespacing on Mac, GNU+Linux and Windows.
-
-    Mac OS X uses the hhea values.
-    Windows uses OS/2 or Win, depending on the OS or fsSelection bit value.
-    """
+    """Checking OS/2 Metrics match hhea Metrics."""
 
     filename = os.path.basename(ttFont.reader.file.name)
 
@@ -204,12 +208,14 @@ def com_google_fonts_check_family_single_directory(fonts):
     if len(directories) == 1:
         yield PASS, "All files are in the same directory."
     else:
-        yield FAIL, (f"Not all fonts passed in the command line"
-                     f" are in the same directory. This may lead to"
-                     f" bad results as the tool will interpret all"
-                     f" font files as belonging to a single"
-                     f" font family. The detected directories are:"
-                     f" {directories}")
+        yield FAIL, \
+              Message("single-directory",
+                      f"Not all fonts passed in the command line"
+                      f" are in the same directory. This may lead to"
+                      f" bad results as the tool will interpret all"
+                      f" font files as belonging to a single"
+                      f" font family. The detected directories are:"
+                      f" {directories}")
 
 
 @condition
@@ -227,7 +233,7 @@ def ftxvalidator_cmd():
         If Font Bakery is not running on an OSX machine, the machine running Font Bakery could access `ftxvalidator` on OSX, e.g. via ssh or a remote procedure call (rpc).
 
         There's an ssh example implementation at:
-        https://github.com/googlefonts/fontbakery/blob/master/prebuilt/workarounds/ftxvalidator/ssh-implementation/ftxvalidator
+        https://github.com/googlefonts/fontbakery/blob/main/prebuilt/workarounds/ftxvalidator/ssh-implementation/ftxvalidator
     """,
     misc_metadata = {
         'request': 'https://github.com/googlefonts/fontbakery/issues/2184'
@@ -238,7 +244,9 @@ def com_google_fonts_check_ftxvalidator_is_available(ftxvalidator_cmd):
     if ftxvalidator_cmd:
         yield PASS, f"ftxvalidator is available at {ftxvalidator_cmd}"
     else:
-        yield WARN, "Could not find ftxvalidator."
+        yield WARN, \
+              Message("ftxvalidator-available",
+                      "Could not find ftxvalidator.")
 
 
 @check(
@@ -258,8 +266,10 @@ def com_google_fonts_check_ftxvalidator(font, ftxvalidator_cmd):
         ]
         # here we capture stdout and stderr separately to avoid
         # corrupting the plist data to be parsed a bit later:
-        pipes = subprocess.Popen(ftx_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        ftx_output, ftx_err = pipes.communicate()
+        with subprocess.Popen(
+            ftx_cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+        ) as pipes:
+            ftx_output, ftx_err = pipes.communicate()
 
         if len(ftx_err):
             yield WARN, \
@@ -300,14 +310,19 @@ def com_google_fonts_check_ots(font):
     try:
         process = ots.sanitize(font, check=True, capture_output=True)
     except ots.CalledProcessError as e:
-        yield FAIL, (
-            "ots-sanitize returned an error code ({}). Output follows:\n\n{}{}"
-        ).format(e.returncode, e.stderr.decode(), e.stdout.decode())
+        yield FAIL, \
+              Message("ots-sanitize-error",
+                ("ots-sanitize returned an error code ({}). Output follows:\n\n{}{}"
+                ).format(e.returncode, e.stderr.decode(), e.stdout.decode())
+              )
     else:
         if process.stderr:
-            yield WARN, (
-                "ots-sanitize passed this file, however warnings were printed:\n\n{}"
-            ).format(process.stderr.decode())
+            yield WARN, \
+                  Message("ots-sanitize-warn",
+                          ("ots-sanitize passed this file, "
+                          "however warnings were printed:\n\n{}"
+                          ).format(process.stderr.decode())
+                  )
         else:
             yield PASS, "ots-sanitize passed this file"
 
@@ -554,6 +569,7 @@ def com_google_fonts_check_whitespace_ink(ttFont):
 def com_google_fonts_check_required_tables(ttFont):
     """Font contains all required tables?"""
     from .shared_conditions import is_variable_font
+    from fontbakery.utils import bullet_list
 
     REQUIRED_TABLES = ["cmap", "head", "hhea", "hmtx",
                        "maxp", "name", "OS/2", "post"]
@@ -576,8 +592,11 @@ def com_google_fonts_check_required_tables(ttFont):
 
     optional_tables = [opt for opt in OPTIONAL_TABLES if opt in ttFont.keys()]
     if optional_tables:
-        yield INFO, ("This font contains the following"
-                     " optional tables [{}]").format(", ".join(optional_tables))
+        yield INFO, \
+              Message("required-tables",
+                      f"This font contains the following optional tables:\n"
+                      f"{bullet_list(optional_tables)}"
+                     )
 
     if is_variable_font(ttFont):
         # According to https://github.com/googlefonts/fontbakery/issues/1671
@@ -590,8 +609,10 @@ def com_google_fonts_check_required_tables(ttFont):
         missing_tables.append("CFF ' or 'glyf")
 
     if missing_tables:
-        yield FAIL, ("This font is missing the following required tables:"
-                     " ['{}']").format("', '".join(missing_tables))
+        yield FAIL, \
+              Message("required-tables",
+                      f"This font is missing the following required tables:\n"
+                      f"{bullet_list(missing_tables)}")
     else:
         yield PASS, "Font contains all required tables."
 
@@ -627,10 +648,13 @@ def com_google_fonts_check_unwanted_tables(ttFont):
             unwanted_tables_found.append(f'Table: {table}\nReason: {info}\n')
 
     if len(unwanted_tables_found) > 0:
-        yield FAIL, ("The following unwanted font tables were found:\n"
+        yield FAIL, \
+              Message("unwanted-tables",
+                     ("The following unwanted font tables were found:\n"
                      "{}\n"
                      "They can be removed with the gftools fix-unwanted-tables script."
                      ).format("\n".join(unwanted_tables_found))
+                     )
     else:
         yield PASS, "There are no unwanted tables."
 
@@ -692,7 +716,7 @@ def com_google_fonts_check_STAT_strings(ttFont):
     id = 'com.google.fonts/check/valid_glyphnames',
     rationale = """
         Microsoft's recommendations for OpenType Fonts states the following:
-    
+
         'NOTE: The PostScript glyph name must be no longer than 31 characters, include only uppercase or lowercase English letters, European digits, the period or the underscore, i.e. from the set [A-Za-z0-9_.] and should start with a letter, except the special glyph name ".notdef" which starts with a period.'
 
         https://docs.microsoft.com/en-us/typography/opentype/spec/recom#post-table
@@ -788,8 +812,10 @@ def com_google_fonts_check_unique_glyphnames(ttFont):
         if len(duplicated_glyphIDs) == 0:
             yield PASS, "Font contains unique glyph names."
         else:
-            yield FAIL, (f"The following glyph names"
-                         f" occur twice: {duplicated_glyphIDs}")
+            yield FAIL, \
+                  Message("duplicated-glyph-names",
+                          "The following glyph names occur twice: "
+                          f"{duplicated_glyphIDs}")
 
 
 # This check was originally ported from
@@ -815,7 +841,9 @@ def com_google_fonts_check_glyphnames_max_length(ttFont):
         for name in ttFont.getGlyphOrder():
             if len(name) > 109:
                 failed = True
-                yield FAIL, f"Glyph name is too long: '{name}'"
+                yield FAIL, \
+                    Message("glyphname-too-long",
+                            f"Glyph name is too long: '{name}'")
         if not failed:
             yield PASS, "No glyph names exceed max allowed length."
 
@@ -1031,8 +1059,10 @@ def com_google_fonts_check_superfamily_vertical_metrics(superfamily_ttFonts):
         for k in warn:
             s = ["{}: {}".format(k, v) for k, v in vmetrics[k].items()]
             s = "\n".join(s)
-            yield WARN, (f"{k} is not the same across the super-family:\n"
-                         f"{s}")
+            yield WARN, \
+                  Message("superfamily-vertical-metrics",
+                          f"{k} is not the same across the super-family:\n"
+                          f"{s}")
     else:
         yield PASS, "Vertical metrics are the same across the super-family."
 
