@@ -382,7 +382,7 @@ class TerminalReporter(TerminalProgress):
             self._collected_results[key][message.name] += 1
 
     def _render_event_sync(self, print, event):
-        status, message, (section, check, iterargs) = event
+        status, msg, (section, check, iterargs) = event
 
         if not status.weight >= self._structure_threshold \
            or status in self._skip_status_report:
@@ -440,19 +440,38 @@ class TerminalReporter(TerminalProgress):
         # Log statuses have weights >= 0
         # log_statuses = (INFO, WARN, PASS, SKIP, FAIL, ERROR, DEBUG)
         if status.weight >= self._log_threshold:
-            print('    * {}: {}'.format(formatStatus(self.theme, status),
-                                        message))
-            if hasattr(message, 'traceback'):
-                print('        ','\n         '.join(message.traceback.split('\n')))
+            print('')
 
+            from fontbakery.utils import text_flow
+            status_name = getattr(status, 'name', status)
+
+            try:
+                message = (f"{msg.message}\n"
+                           f"[code: {msg.code}]")
+            except:
+                message = str(msg)
+
+            if hasattr(msg, 'traceback'):
+                message += '\n' + '\n  ↳ '.join(msg.traceback.split('\n'))
+
+            formated_msg = '{} {}'.format(formatStatus(self.theme, status), message)
+            formated_msg = parse_md(formated_msg)
+            if hasattr(message, 'traceback'):
+                formated_msg += '\n' + '\n  ↳ '.join(message.traceback.split('\n'))
+            print(text_flow(formated_msg,
+                            width=76,
+                            indent=4,
+                            first_line_indent=-1-len(status_name),
+                            left_margin=6,
+                            space_padding=True))
 
         if status == ENDCHECK:
             if not self.succinct:
                 print('\n')
-            print('    Result: {}\n'.format(formatStatus(self.theme, message)))
+            print('    Result: {}\n'.format(formatStatus(self.theme, msg)))
 
         if status == SECTIONSUMMARY:
-            order, counter = message
+            order, counter = msg
             print('')
             print('='*8, f'Section results: {section}','='*8)
             print('{} {} in section'.format(len(order)
@@ -479,7 +498,7 @@ class TerminalReporter(TerminalProgress):
 
             print('Total:')
             print('')
-            print(_render_results_counter(self.theme, message))
+            print(_render_results_counter(self.theme, msg))
             print('')
 
             # same end message as parent
@@ -554,3 +573,92 @@ class TerminalReporter(TerminalProgress):
             self._render_event_sync(print, event)
 
         return output.getvalue()
+
+def parse_md(md):
+    from rich.console import Console
+    from rich.markdown import Markdown
+    import re
+    table_re = r'(^|[^|]\n)((?:^\|[^\n]*\|(?:\n|$))+)([^|]|$)'
+    md = re.sub(r'\n([\r\t ]*\n)+', r'\n\n', md, flags=re.MULTILINE)
+    md = re.sub(r'^[\t ]*\|', r'|', md, flags=re.MULTILINE)
+    md = re.sub(r'\|[\t ]*$', r'|', md, flags=re.MULTILINE)
+    tables = []
+    md = re.sub(table_re, lambda match: parse_md_table(match, tables), md,
+                flags=re.MULTILINE | re.S)
+    console = Console(width=70)
+    with console.capture() as capture:
+        console.print(Markdown(md))
+    formated_text = capture.get()
+    for i in range(len(tables)):
+        formated_text = re.sub('<#MD-TABLE-'+str(i)+'#>', tables[i], formated_text)
+    return re.sub(r'<br/?>', r'\n', formated_text).strip()
+
+def parse_md_table(match, tables_memo):
+    from rich.console import Console
+    from rich.table import Table
+    from rich.style import Style
+    from rich.align import Align
+    from rich import box
+    import re
+    [table_header, table_body, columns] = split_md_table(match.group(2))
+    b = box.Box('    \n    \n══╪═\n    \n┈┈┼┈\n┈┈┼┈\n    \n    ')
+    table = Table(box=b, show_header=False, show_edge=False, border_style=Style(color='#222222'))
+    for col_align in columns:
+        table.add_column(None, justify=col_align)
+    sty_header = Style(bgcolor='blue', color='#000000', bold=True)
+    sty_odd = Style(bgcolor="#111111", color='white')
+    sty_even = Style(bgcolor="#222222", color='white')
+    for row in table_header:
+        row = map(Align.center, row)
+        table.add_row(*row, style=sty_header)
+    num = 0
+    for row in table_body:
+        num += 1
+        style = sty_even if (num % 2 == 0) else sty_odd
+        table.add_row(*row, style=style)
+
+    console = Console(width=70)
+    with console.capture() as capture:
+        console.print(table)
+    formated_text = '\n'.join(capture.get().split('\n')[0:-1])
+    before = '' if match.group(1) == '\n\n' else '\n'
+    after = '  ' if match.group(3) == '\n' else '  \n'
+    tables_memo.append(before + formated_text)
+    return match.group(1) + \
+           '<#MD-TABLE-'+str(len(tables_memo)-1)+'#>' + after + \
+           match.group(3)
+
+def map_md_table_align_col(cell):
+    import re
+    if re.match(r'^\s*:-+:\s*$', cell):
+        return 'center'
+    if re.match(r'^\s*-+:\s*$', cell):
+        return 'right'
+    return 'left'
+
+def split_md_table(md_table):
+    import re
+    md_table = re.sub(r'^\||\|$', '', md_table, flags=re.MULTILINE)
+    table_header = []
+    table_body = []
+    columns = []
+    table = list(map(
+        lambda row:
+            list(map(lambda cell: cell.strip(), row.split('|'))),
+        md_table.strip().split('\n')
+    ))
+    has_header = False
+    for row in table:
+        if re.match(r'^\s*:?-+:?\s*$', row[0]):
+            has_header = True
+    in_header = has_header
+    for row in table:
+        if in_header:
+            if re.match(r'^\s*:?-+:?\s*$', row[0]):
+                in_header = False
+                columns = map(map_md_table_align_col, row)
+            else:
+                table_header.append(row)
+        else:
+            table_body.append(row)
+    return [table_header, table_body, columns]
